Package: elmNNRcpp
Type: Package
Title: The Extreme Learning Machine Algorithm
Version: 1.0.4
Date: 2022-01-27
Authors@R: c( person(given = "Lampros", family = "Mouselimis", email = "mouselimislampros@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "https://orcid.org/0000-0002-8024-1546")), person(given = "Alberto", family = "Gosso", email = "gosso.alberto@gmail.com", role = "aut"), person(given = "Edwin", family = "de Jonge", email = "edwindjonge@gmail.com", role = "ctb", comment = c(ORCID = "https://orcid.org/0000-0002-6580-4718", Github = "Github Contributor")) )
BugReports: https://github.com/mlampros/elmNNRcpp/issues
URL: https://github.com/mlampros/elmNNRcpp
Description: Training and predict functions for Single Hidden-layer Feedforward Neural Networks (SLFN) using the Extreme Learning Machine (ELM) algorithm. The ELM algorithm differs from the traditional gradient-based algorithms for very short training times (it doesn't need any iterative tuning, this makes learning time very fast) and there is no need to set any other parameters like learning rate, momentum, epochs, etc. This is a reimplementation of the 'elmNN' package using 'RcppArmadillo' after the 'elmNN' package was archived. For more information, see "Extreme learning machine: Theory and applications" by Guang-Bin Huang, Qin-Yu Zhu, Chee-Kheong Siew (2006), Elsevier B.V, <doi:10.1016/j.neucom.2005.12.126>.
License: GPL (>= 2)
Encoding: UTF-8
Depends: R(>= 3.0.2), KernelKnn
Imports: Rcpp (>= 0.12.17)
LinkingTo: Rcpp, RcppArmadillo (>= 0.8)
Suggests: testthat, covr, knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 7.1.2
NeedsCompilation: yes
Packaged: 2022-01-27 19:08:20 UTC; lampros
Author: Lampros Mouselimis [aut, cre] (<https://orcid.org/0000-0002-8024-1546>),
  Alberto Gosso [aut],
  Edwin de Jonge [ctb] (<https://orcid.org/0000-0002-6580-4718>, Github
    Contributor)
Maintainer: Lampros Mouselimis <mouselimislampros@gmail.com>
Repository: CRAN
Date/Publication: 2022-01-28 03:20:07 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-24 15:25:27 UTC; unix
Archs: elmNNRcpp.so.dSYM
