# Generated by roxygen2: do not edit by hand

S3method(fitted,elm)
S3method(predict,elm)
S3method(print,elm)
S3method(residuals,elm)
export(elm)
export(elm_predict)
export(elm_train)
export(onehot_encode)
import(KernelKnn)
importFrom(Rcpp,evalCpp)
useDynLib(elmNNRcpp, .registration = TRUE)
